@@ -1,7 +1,7 @@
 /* -*- mia-c++  -*-
  *
  * This file is part of MIA - a toolbox for medical image analysis 
- * Copyright (c) Leipzig, Madrid 1999-2013 Gert Wollny
+ * Copyright (c) Leipzig, Madrid 1999-2014 Gert Wollny
  *
  * MIA is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -47,8 +47,10 @@ CDicom3DImageIOPlugin::CDicom3DImageIOPlugin():
 	C3DImageIOPlugin("dicom")
 {
 	add_supported_type(it_ushort);
+	add_supported_type(it_sshort);
 
 	TTranslator<float>::register_for("SliceLocation");
+	TTranslator<double>::register_for("AcquisitionTime"); 
 	TTranslator<int>::register_for("SeriesNumber");
 	TTranslator<int>::register_for("AcquisitionNumber");
 	TTranslator<int>::register_for("InstanceNumber");
@@ -164,7 +166,7 @@ static P3DImage get_3dimage(CImageInstances& slices)
 	return creator.get_image();
 }
 
-std::string CDicom3DImageIOPlugin::do_get_preferred_suffix() const
+const std::string CDicom3DImageIOPlugin::do_get_preferred_suffix() const
 {
 	return "dcm"; 
 }
@@ -316,10 +318,18 @@ bool CSliceSaver::operator () ( const T3DImage<T>& image) const
 
 	C3DFVector voxel = image.get_voxel_size();
 	C2DFVector pixel(voxel.x, voxel.y);
-
-
+	
+	auto origin = image.get_origin();
+	auto rotation = image.get_rotation();
+	
 	T2DImage<T> slice = image.get_data_plane_xy(m_slice);
+	slice.set_attributes(image.begin_attributes(), image.end_attributes()); 
 	slice.set_pixel_size(pixel);
+	slice.set_attribute("rotation3d", PAttribute(new C3DRotationAttribute(rotation)));
+
+	
+	C3DFVector new_origin = C3DFVector(rotation.as_matrix_3x3() * C3DDVector(0,0,m_slice)) + origin;
+	slice.set_attribute("origin3d", PAttribute(new CVoxelAttribute(new_origin))); 
 
 	slice.set_attribute(IDInstanceNumber, PAttribute(new CIntAttribute(m_slice + 1)));
 	slice.set_attribute(IDSliceLocation,  PAttribute(new CFloatAttribute(m_location)));
@@ -328,8 +338,8 @@ bool CSliceSaver::operator () ( const T3DImage<T>& image) const
 	if (!slice.has_attribute(IDSeriesNumber))
 		slice.set_attribute(IDSeriesNumber, PAttribute(new CIntAttribute(m_series + 1)));
 
-	CDicomWriter weiter(slice);
-	return weiter.write(fname.str().c_str());
+	CDicomWriter writer(slice);
+	return writer.write(fname.str().c_str());
 }
 
 bool CDicom3DImageIOPlugin::do_save(const string& fname, const Data& data) const
