@@ -1,7 +1,7 @@
 /* -*- mia-c++  -*-
  *
  * This file is part of MIA - a toolbox for medical image analysis 
- * Copyright (c) Leipzig, Madrid 1999-2013 Gert Wollny
+ * Copyright (c) Leipzig, Madrid 1999-2014 Gert Wollny
  *
  * MIA is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -250,7 +250,7 @@ void CNLOptFDFMinimizer::do_set_problem()
 
 	if (m_options.max_boundary != HUGE_VAL) {
 		cvinfo() << "Set higher boundary to " << m_options.max_boundary << "\n"; 
-		nlopt_set_lower_bounds1(m_opt, m_options.max_boundary); 
+		nlopt_set_upper_bounds1(m_opt, m_options.max_boundary); 
 	}
 	
 	if (m_options.step > 0.0)
