@@ -98,12 +98,9 @@ void MyErrorHandler(const char *module, const char *fmt,  va_list ap)
 {
 	char buf[16384];
 	snprintf(buf,16384, fmt, ap);
-
-	cverr() << module << ":" << buf << "\n";
-	exit(1);
+	throw create_exception<runtime_error>(module, ":", buf);
 }
 
-
 struct CErrorHandlerReplacer {
 	CErrorHandlerReplacer():
 		m_old_handler(TIFFSetErrorHandler(MyErrorHandler))
@@ -245,6 +242,7 @@ P2DImage read_strip_pixels(CTiffFile& tif, unsigned int width,
 
 CTiff2DImageIO::PData CTiff2DImageIO::do_load(string const& filename)const
 {
+	CErrorHandlerReplacer error_handing;
 	CTiffFile tif(filename.c_str(), "r");
 	if (!tif)
 		return PData();
