@@ -1,7 +1,7 @@
 /* -*- mia-c++  -*-
  *
  * This file is part of MIA - a toolbox for medical image analysis 
- * Copyright (c) Leipzig, Madrid 1999-2013 Gert Wollny
+ * Copyright (c) Leipzig, Madrid 1999-2014 Gert Wollny
  *
  * MIA is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -25,21 +25,13 @@
 NS_MIA_USE
 namespace bfs=::boost::filesystem; 
 using namespace boost::unit_test;
-
-CSplineKernelTestPath spline_kernel_set_test_path; 
+using std::set; 
+using std::string; 
 
 BOOST_AUTO_TEST_CASE( test_2dimage_cost_avail )
 {
-	CPathNameArray searchpath; 
-	
-	searchpath.push_back(bfs::path("cost")); 
-
-	C2DImageCostPluginHandler::set_search_path(searchpath); 
-	
-	const auto& handler = C2DImageCostPluginHandler::instance(); 
-
-	BOOST_CHECK_EQUAL(handler.size(), 4u); 
-	BOOST_CHECK_EQUAL(handler.get_plugin_names(), "lsd mi ngf ssd "); 
+	set<string> test_data = {"lncc","lsd", "mi", "ngf", "ncc", "ssd", "ssd-automask"}; 
+	test_pluginsets(C2DImageCostPluginHandler::instance().get_set(), test_data); 
 }
 
 
