@@ -1,7 +1,7 @@
 /* -*- mia-c++  -*-
  *
  * This file is part of MIA - a toolbox for medical image analysis 
- * Copyright (c) Leipzig, Madrid 1999-2013 Gert Wollny
+ * Copyright (c) Leipzig, Madrid 1999-2014 Gert Wollny
  *
  * MIA is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -21,6 +21,7 @@
 #include <mia/internal/autotest.hh>
 #include <boost/filesystem/path.hpp>
 
+#include <mia/core/attribute_names.hh>
 #include <mia/core/msgstream.hh>
 #include <mia/2d/imageio.hh>
 
@@ -30,8 +31,6 @@ using namespace boost;
 using namespace boost::unit_test;
 namespace bfs = ::boost::filesystem; 
 
-C2DImageIOPluginHandlerTestPath test_imageio_path; 
-
 static P2DImage create_test_image(int acquisition, int instance, const string& protocol) 
 {
 	C2DSIImage *image = new C2DSIImage(C2DBounds(1,2)); 
