@@ -1,7 +1,7 @@
 /* -*- mia-c++  -*-
  *
  * This file is part of MIA - a toolbox for medical image analysis 
- * Copyright (c) Leipzig, Madrid 1999-2013 Gert Wollny
+ * Copyright (c) Leipzig, Madrid 1999-2014 Gert Wollny
  *
  * MIA is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -21,8 +21,8 @@
 #include <mia/internal/autotest.hh>
 
 #include <numeric>
-#include <mia/2d/SegSetWithImages.hh>
-#include <mia/2d/BoundingBox.hh>
+#include <mia/2d/segsetwithimages.hh>
+#include <mia/2d/boundingbox.hh>
 #include <mia/2d/transformfactory.hh>
 #include <mia/2d/imageio.hh>
 
@@ -30,13 +30,13 @@
 
 namespace bfs=boost::filesystem;
 
+
 NS_MIA_USE
 using namespace std;
 using namespace ::boost;
 using namespace ::boost::unit_test;
 using namespace xmlpp;
 
-
 const char *testpoint_init  =
 	"<?xml version=\"1.0\" encoding=\"UTF-8\"?>\n<test><point y=\"20\" x=\"10\"/></test>\n";
 
@@ -402,9 +402,9 @@ BOOST_AUTO_TEST_CASE(test_segstart_error_attribute)
 input_set.save_images(); 
 */
 
-BOOST_AUTO_TEST_CASE( test_segset_write )
+BOOST_AUTO_TEST_CASE( test_segset_write_version1 )
 {
-	CSegSet segset;
+	CSegSet segset(1);
 	CSegStar star1(CSegPoint2D(109, 118), 21, CSegPoint2D(10, 20),
 		       CSegPoint2D(20, 10), CSegPoint2D(0, 4));
 	CSegStar star2(CSegPoint2D(109, 118), 22, CSegPoint2D(10, 20),
