@@ -1,7 +1,7 @@
 /* -*- mia-c++  -*-
  *
  * This file is part of MIA - a toolbox for medical image analysis 
- * Copyright (c) Leipzig, Madrid 1999-2013 Gert Wollny
+ * Copyright (c) Leipzig, Madrid 1999-2014 Gert Wollny
  *
  * MIA is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -161,40 +161,6 @@ void C2DRigidTransformation::set_parameters(const CDoubleVector& params)
 	m_matrix_valid = false;
 }
 
-float C2DRigidTransformation::divergence() const
-{
-	return 0.0;
-}
-
-float C2DRigidTransformation::grad_divergence() const
-{
-	return 0.0;
-}
-
-
-float C2DRigidTransformation::grad_curl() const
-{
-	return 0.0;
-}
-
-
-float C2DRigidTransformation::curl() const
-{
-	// this is not right
-	return m_rotation;
-}
-
-double C2DRigidTransformation::get_divcurl_cost(double /*wd*/, double /*wr*/, CDoubleVector& /*gradient*/) const
-{
-	return 0.0; 
-}
-
-double C2DRigidTransformation::get_divcurl_cost(double /*wd*/, double /*wr*/) const
-{
-	return 0.0; 
-}
-
-
 const C2DBounds& C2DRigidTransformation::get_size() const
 {
 	return m_size;
