@@ -1,7 +1,7 @@
 /* -*- mia-c++  -*-
  *
  * This file is part of MIA - a toolbox for medical image analysis 
- * Copyright (c) Leipzig, Madrid 1999-2013 Gert Wollny
+ * Copyright (c) Leipzig, Madrid 1999-2014 Gert Wollny
  *
  * MIA is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -24,6 +24,7 @@
 #include <iomanip>
 #include <numeric>
 #include <mia/2d/transform/spline.hh>
+#include <mia/2d/transform/vectorfield.hh>
 #include <mia/2d/transformfactory.hh>
 
 
@@ -207,6 +208,11 @@ void C2DSplineTransformation::reinit()
 	}
 }
 
+C2DBounds C2DSplineTransformation::get_minimal_supported_image_size() const
+{
+	return C2DBounds(ceil(m_target_c_rate.x), ceil(m_target_c_rate.y)) + C2DBounds::_1; 
+}
+
 C2DFVector C2DSplineTransformation::interpolate(const C2DFVector& x) const 
 {
 	TRACE_FUNCTION;
@@ -242,10 +248,30 @@ C2DTransformation *C2DSplineTransformation::do_clone()const
 	return new C2DSplineTransformation(*this);
 }
 
+C2DFVector C2DSplineTransformation::find_inverse(const C2DBounds& x) const 
+{
+	C2DFVector r(x);
+	int niter = 0; 
+	C2DFVector delta = (*this)(r) - r;
+	while (delta.norm2() > 0.000001 && niter++ < 100) {
+		r -= 0.1 * delta; 
+		delta = (*this)(r) - r; 
+	}
+	return r; 
+}
+
 C2DTransformation *C2DSplineTransformation::invert() const
 {
 	assert(0 && "not implemented"); 
-	return new C2DSplineTransformation(*this);
+	C2DGridTransformation *result = new C2DGridTransformation(get_size(), get_interpolator_factory());
+	
+	auto iv = result->field_begin(); 
+	
+	for (unsigned y = 0; y < get_size().y; ++y) 
+		for (unsigned x = 0; x < get_size().x; ++x, ++iv) 
+			*iv = find_inverse(C2DBounds(x,y)); 
+
+	return result;
 }
 
 
@@ -661,35 +687,6 @@ void C2DSplineTransformation::iterator_impl::do_y_increment()
 	m_value_valid = false; 
 }
 
-
-double C2DSplineTransformation::get_divcurl_cost(double wd, double wr, CDoubleVector& gradient) const
-{
-	// create PP matrices or adapt size 
-	if (!m_divcurl_matrix) 
-		m_divcurl_matrix.reset(new C2DPPDivcurlMatrix(m_coefficients.get_size(), m_range, 
-							       *m_kernel, wd, wr)); 
-	else 
-		m_divcurl_matrix->reset(m_coefficients.get_size(), m_range, 
-					 *m_kernel, wd, wr); 
-	
-	
-	return m_divcurl_matrix->evaluate(m_coefficients, gradient); 
-}
-
-double C2DSplineTransformation::get_divcurl_cost(double wd, double wr) const
-{
-	// create PP matrices or adapt size 
-	if (!m_divcurl_matrix) 
-		m_divcurl_matrix.reset(new C2DPPDivcurlMatrix(m_coefficients.get_size(), m_range, 
-							       *m_kernel, wd, wr)); 
-	else 
-		m_divcurl_matrix->reset(m_coefficients.get_size(), m_range, 
-					 *m_kernel, wd, wr); 
-	
-
-	return *m_divcurl_matrix * m_coefficients; 
-}
-
 double C2DSplineTransformation::do_get_energy_penalty_and_gradient(CDoubleVector& gradient) const
 {
 	assert(m_penalty); 
@@ -736,20 +733,6 @@ P2DTransformation C2DSplineTransformCreator::do_create(const C2DBounds& size, co
 }
 
 
-
-
-class C2DSplineTransformCreatorPlugin: public C2DTransformCreatorPlugin {
-public:
-	C2DSplineTransformCreatorPlugin();
-	virtual C2DTransformCreator *do_create(const C2DInterpolatorFactory& ipf) const;
-	const std::string do_get_descr() const;
-private:
-	PSplineKernel m_interpolator;
-	float m_rate; 
-	C2DFVector m_rate2d;
-	P2DSplineTransformPenalty m_penalty; 
-};
-
 C2DSplineTransformCreatorPlugin::C2DSplineTransformCreatorPlugin():
 	C2DTransformCreatorPlugin("spline"),
 	m_rate(10), 
@@ -781,7 +764,10 @@ const std::string C2DSplineTransformCreatorPlugin::do_get_descr() const
 
 extern "C" EXPORT CPluginBase *get_plugin_interface()
 {
-	return new C2DSplineTransformCreatorPlugin();
+	auto p = new C2DGridTransformCreatorPlugin();
+	p->append_interface(new C2DSplineTransformCreatorPlugin()); 
+	return p; 
+
 }
 
 NS_MIA_END
