@@ -1,7 +1,7 @@
 /* -*- mia-c++  -*-
  *
  * This file is part of MIA - a toolbox for medical image analysis 
- * Copyright (c) Leipzig, Madrid 1999-2013 Gert Wollny
+ * Copyright (c) Leipzig, Madrid 1999-2014 Gert Wollny
  *
  * MIA is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -20,7 +20,6 @@
 
 #include <cmath>
 #include <fstream>
-#include <mia/internal/autotest.hh>
 
 #include <mia/core/spacial_kernel.hh>
 #include <mia/2d/interpolator.hh>
@@ -34,8 +33,6 @@ using namespace ::boost;
 using namespace boost::unit_test;
 namespace bfs=boost::filesystem;
 
-CSplineKernelTestPath init_path; 
-
 struct TransformSplineFixture {
 	TransformSplineFixture():
 		size(33,65),
