@@ -1,7 +1,7 @@
 /* -*- mia-c++  -*-
  *
  * This file is part of MIA - a toolbox for medical image analysis 
- * Copyright (c) Leipzig, Madrid 1999-2013 Gert Wollny
+ * Copyright (c) Leipzig, Madrid 1999-2014 Gert Wollny
  *
  * MIA is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -22,17 +22,25 @@
 
 #include <mia/core/errormacro.hh>
 #include <mia/2d/transformio.hh>
+#include <mia/2d/defines2d.hh>
 #include <mia/core/ioplugin.cxx>
 #include <mia/core/iohandler.cxx>
 
 NS_MIA_BEGIN
 
+C2DTransformIOPluginHandlerImpl::C2DTransformIOPluginHandlerImpl()
+{
+	TTranslator<C2DFVector>::register_for(C2DTransformation::input_spacing_attr);
+	TTranslator<C2DFVector>::register_for(C2DTransformation::output_spacing_attr);
+}
+
+
 template <> const char *  const 
 	TPluginHandler<C2DTransformationIO>::m_help =  
        "These plug-ins implement the support for loading and storing 2D transformations to various file types.";
 
 template class TIOPlugin<C2DTransformation>;
-template class THandlerSingleton<TIOPluginHandler<C2DTransformationIO> >;
+template class THandlerSingleton<C2DTransformIOPluginHandlerImpl>;
 template class TIOPluginHandler<C2DTransformationIO>;
 template class TPluginHandler<C2DTransformationIO>;
 
