@@ -1,7 +1,7 @@
 /* -*- mia-c++  -*-
  *
  * This file is part of MIA - a toolbox for medical image analysis 
- * Copyright (c) Leipzig, Madrid 1999-2013 Gert Wollny
+ * Copyright (c) Leipzig, Madrid 1999-2014 Gert Wollny
  *
  * MIA is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -25,14 +25,30 @@ NS_BEGIN( transform_3dimage_filter)
 
 NS_MIA_USE; 
 
-C3DTransform::C3DTransform(const std::string& name):
-	m_name(name)
+C3DTransform::C3DTransform(const std::string& name, const std::string& kernel, const std::string& bc):
+m_name(name), 
+	m_kernel(kernel), 
+	m_bc(bc)
 {
 }
 
 mia::P3DImage C3DTransform::do_filter(const mia::C3DImage& image) const
 {
         auto transform = load_transform<P3DTransformation>(m_name); 
+	if (!m_kernel.empty()) {
+		if (m_bc.empty()) {
+			cvdebug() << "Override interpolator with kernel="
+				  << m_kernel << " and mirror boundary conditions\n"; 
+			C3DInterpolatorFactory ipf(m_kernel, "mirror");
+			transform->set_interpolator_factory(ipf); 
+		}else{
+			cvdebug() << "Override interpolator with kernel="
+				  << m_kernel << " and "<< m_bc << " boundary conditions\n"; 
+			C3DInterpolatorFactory ipf(m_kernel, m_bc);
+			transform->set_interpolator_factory(ipf); 
+		}
+	}
+	
         return (*transform)(image); 
 	
 }
@@ -40,14 +56,26 @@ mia::P3DImage C3DTransform::do_filter(const mia::C3DImage& image) const
 C3DTransformFilterPluginFactory::C3DTransformFilterPluginFactory(): 
 	C3DFilterPlugin("transform")
 {
-	add_parameter("file", new CStringParameter(m_filename, true,
+	add_parameter("file", new CStringParameter(m_filename, CCmdOptionFlags::required_input,
 						   "Name of the file containing the transformation.", 
 						   &C3DTransformationIOPluginHandler::instance()));
+
+	
+	add_parameter("imgkernel", new CStringParameter(m_interpolator_kernel, CCmdOptionFlags::none, 
+							"override image interpolator kernel", 
+							&CSplineKernelPluginHandler::instance()));
+	add_parameter("imgboundary", new CStringParameter(m_interpolator_bc, CCmdOptionFlags::none, 
+							  "override image interpolation boundary conditions", 
+							  &CSplineBoundaryConditionPluginHandler::instance())); 
+ 
+
 }
 
 mia::C3DFilter *C3DTransformFilterPluginFactory::do_create()const
 {
-	return new C3DTransform(m_filename); 
+	
+
+	return new C3DTransform(m_filename, m_interpolator_kernel, m_interpolator_bc); 
 }
 
 const std::string C3DTransformFilterPluginFactory::do_get_descr()const
