@@ -1,7 +1,7 @@
 /* -*- mia-c++  -*-
  *
  * This file is part of MIA - a toolbox for medical image analysis 
- * Copyright (c) Leipzig, Madrid 1999-2013 Gert Wollny
+ * Copyright (c) Leipzig, Madrid 1999-2014 Gert Wollny
  *
  * MIA is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -110,17 +110,17 @@ struct analyze_dsr
 #pragma pack()
 
 /* Acceptable values for datatype */
-#define DT_NONE                      0
-#define DT_UNKNOWN                   0
-#define DT_BINARY                    1
-#define DT_UNSIGNED_CHAR             2
-#define DT_SIGNED_SHORT              4
-#define DT_SIGNED_INT                8
-#define DT_FLOAT                     16
-#define DT_COMPLEX                   32
-#define DT_DOUBLE                    64
-#define DT_RGB                       128
-#define DT_ALL                       255
+#define DTA_NONE                      0
+#define DTA_UNKNOWN                   0
+#define DTA_BINARY                    1
+#define DTA_UNSIGNED_CHAR             2
+#define DTA_SIGNED_SHORT              4
+#define DTA_SIGNED_INT                8
+#define DTA_FLOAT                     16
+#define DTA_COMPLEX                   32
+#define DTA_DOUBLE                    64
+#define DTA_RGB                       128
+#define DTA_ALL                       255
 
 enum EAnaOrientation {
 	ao_transverse_unflipped = 0,
@@ -293,7 +293,7 @@ void swap_endian(T3DImage<T>& image)
 }
 
 
-template <typename T, bool flipped>
+template <typename T>
 struct do_read_image {
 	static C3DImage * apply(const C3DBounds& size, CInputFile& data_file, bool do_swap_endian) {
 		T3DImage<T> *result = new T3DImage<T>(size);
@@ -305,50 +305,19 @@ struct do_read_image {
 	}
 };
 
-template <typename T>
-struct do_read_image<T, true> {
-	static C3DImage * apply(const C3DBounds& size, CInputFile& data_file, bool do_swap_endian) {
-		T3DImage<T> *result = new T3DImage<T>(size);
-		for (size_t z = size.z; z > 0; --z)
-			if (fread(&(*result)(0,0,z - 1), sizeof(T), result->size(), data_file) != result->size())
-				throw runtime_error("Analyze: unable to read data");
-		if (do_swap_endian)
-			swap_endian(*result);
-		return result;
-	}
-};
 
-
-#if 0
-template <>
-struct do_read_image<bool> {
-	static C3DImage * apply(const C3DBounds& size, CInputFile& data_file, bool swap_endian) const {
-
-
-		T3DImage<bool> *result = new T3DImage<bool>(size);
-		if (fread(&(*result)(0,0,0), sizeof(T), result->size(), data_file) != result->size())
-			throw runtime_error("Analyze: unable to read data");
-		if (swap_endian)
-			swap_endian(*result);
-		return result;
-	}
-};
-
-#endif
-
-template <bool flipped>
 C3DImage *CAnalyze3DImageIOPlugin::read_image(const C3DBounds& size, short datatype, CInputFile& data_file) const
 {
 	if (datatype & 128)
 		cvwarn() << "Got an RGB indicator but I will ignore it\n";
 
 	switch (datatype & 0xFF) {
-//	case DT_BINARY       :return do_read_image<bool>::apply(size, data_file, m_swap_endian);
-	case DT_UNSIGNED_CHAR:return do_read_image<unsigned char, flipped>::apply(size, data_file, m_swap_endian);
-	case DT_SIGNED_SHORT :return do_read_image<signed short, flipped>::apply(size, data_file, m_swap_endian);
-	case DT_SIGNED_INT   :return do_read_image<signed int, flipped>::apply(size, data_file, m_swap_endian);
-	case DT_FLOAT        :return do_read_image<float, flipped>::apply(size, data_file, m_swap_endian);
-	case DT_DOUBLE       :return do_read_image<double, flipped>::apply(size, data_file, m_swap_endian);
+//	case DTA_BINARY       :return do_read_image<bool>::apply(size, data_file, m_swap_endian);
+	case DTA_UNSIGNED_CHAR:return do_read_image<unsigned char>::apply(size, data_file, m_swap_endian);
+	case DTA_SIGNED_SHORT :return do_read_image<signed short>::apply(size, data_file, m_swap_endian);
+	case DTA_SIGNED_INT   :return do_read_image<signed int>::apply(size, data_file, m_swap_endian);
+	case DTA_FLOAT        :return do_read_image<float>::apply(size, data_file, m_swap_endian);
+	case DTA_DOUBLE       :return do_read_image<double>::apply(size, data_file, m_swap_endian);
 	default:
 		stringstream msg;
 		msg << "Analyze: unsupported image type:" << datatype;
@@ -361,27 +330,27 @@ void set_typeinfo(analyze_image_dimension& dime, EPixelType pixel_type)
 {
 	switch (pixel_type) {
 	case it_ubyte:
-		dime.datatype = DT_UNSIGNED_CHAR;
+		dime.datatype = DTA_UNSIGNED_CHAR;
 		dime.bitpix   = 8;
 		break;
 
 	case it_sshort:
-		dime.datatype = DT_SIGNED_SHORT;
+		dime.datatype = DTA_SIGNED_SHORT;
 		dime.bitpix   = 16;
 		break;
 
 	case it_sint:
-		dime.datatype = DT_SIGNED_INT;
+		dime.datatype = DTA_SIGNED_INT;
 		dime.bitpix   = 32;
 		break;
 
 	case it_float:
-		dime.datatype = DT_FLOAT;
+		dime.datatype = DTA_FLOAT;
 		dime.bitpix   = 32;
 		break;
 
 	case it_double:
-		dime.datatype = DT_DOUBLE;
+		dime.datatype = DTA_DOUBLE;
 		dime.bitpix   = 64;
 		break;
 
@@ -459,19 +428,20 @@ CAnalyze3DImageIOPlugin::PData CAnalyze3DImageIOPlugin::do_load(const string&  f
 	while (num_img > 0) {
 		--num_img;
 		E3DImageOrientation orientation = ior_unknown;
-		bool unflipped = false;
 		switch ( hdr.hist.orient ) {
-		case ao_transverse_unflipped: unflipped = true;
-		case ao_transverse_flipped: orientation = ior_axial;
+		case ao_transverse_unflipped: orientation = ior_axial;
+			break; 
+		case ao_transverse_flipped: orientation = ior_axial_flipped;
 			break;
-		case ao_coronal_unflipped: unflipped = true;
-		case ao_coronal_flipped:    orientation = ior_coronal;
+		case ao_coronal_unflipped: orientation = ior_coronal;
+			break; 
+		case ao_coronal_flipped:   orientation = ior_coronal_flipped ;
 			break;
-		case ao_saggital_unflipped: unflipped = true;
-		case ao_saggital_flipped:    orientation = ior_saggital;
+		case ao_saggital_unflipped: orientation = ior_saggital;
+			break; 
+		case ao_saggital_flipped:   orientation = ior_saggital_flipped;
 			break;
 		default:
-			unflipped = true;
 			orientation = ior_unknown;
 		}
 		if (voffset < 0) {
@@ -479,12 +449,7 @@ CAnalyze3DImageIOPlugin::PData CAnalyze3DImageIOPlugin::do_load(const string&  f
 				throw create_exception<runtime_error>("Analyze: unable seek in data file '", 
 							      data_file_name, "':", strerror(errno) );
 		}
-		C3DImage *img = unflipped ?
-			read_image<false>(size, hdr.dime.datatype , data_file)
-			:
-			read_image<true>(size, hdr.dime.datatype , data_file);
-
-		P3DImage image(img);
+		P3DImage image(read_image(size, hdr.dime.datatype , data_file));
 		image->set_voxel_size(voxel);
 		image->set_orientation(orientation);
 		result->push_back(image);
@@ -571,18 +536,27 @@ bool CAnalyze3DImageIOPlugin::do_save(const string& fname, const Data& data) con
 	C3DFVector voxel = (*k)->get_voxel_size();
 	EPixelType pixel_type = (*k)->get_pixel_type();
 
-	E3DImageOrientation orient = (*k)->get_orientation();
+	auto orient = (*k)->get_orientation();
 
 	switch (orient) {
 	case ior_axial:
 			hdr.hist.orient = ao_transverse_unflipped;
 			break;
+	case ior_axial_flipped:
+			hdr.hist.orient = ao_transverse_flipped;
+			break;
 	case ior_coronal:
 			hdr.hist.orient = ao_coronal_unflipped;
 			break;
+	case ior_coronal_flipped:
+			hdr.hist.orient = ao_coronal_flipped;
+			break;
 	case ior_saggital:
 			hdr.hist.orient = ao_saggital_unflipped;
 			break;
+	case ior_saggital_flipped:
+			hdr.hist.orient = ao_saggital_flipped;
+			break;
 	default:
 		hdr.hist.orient = ao_unknown;
 	}
@@ -625,7 +599,7 @@ bool CAnalyze3DImageIOPlugin::do_save(const string& fname, const Data& data) con
 	return true;
 }
 
-std::string CAnalyze3DImageIOPlugin::do_get_preferred_suffix() const
+const std::string CAnalyze3DImageIOPlugin::do_get_preferred_suffix() const
 {
 	return "hdr"; 
 }
