@@ -1,7 +1,7 @@
 /* -*- mia-c++  -*-
  *
  * This file is part of MIA - a toolbox for medical image analysis 
- * Copyright (c) Leipzig, Madrid 1999-2013 Gert Wollny
+ * Copyright (c) Leipzig, Madrid 1999-2014 Gert Wollny
  *
  * MIA is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -31,14 +31,6 @@ template <> const char *  const
 TPluginHandler<C3DLandmarklistIOPlugin>::m_help =  
 	"Loading and storing of 3D landmark list.";
 
-C3DLandmarklistIOTestPath::C3DLandmarklistIOTestPath() 
-{
-	CPathNameArray sksearchpath; 
-	sksearchpath.push_back( boost::filesystem::path(MIA_BUILD_ROOT"/mia/3d/lmio"));
-	C3DLandmarklistIOPluginHandler::set_search_path(sksearchpath); 
-
-}
-
 EXPLICITE_INSTANCEIATE_IO_HANDLER(C3DLandmarklist); 
 
 NS_MIA_END
