@@ -1,7 +1,7 @@
 /* -*- mia-c++  -*-
  *
  * This file is part of MIA - a toolbox for medical image analysis 
- * Copyright (c) Leipzig, Madrid 1999-2013 Gert Wollny
+ * Copyright (c) Leipzig, Madrid 1999-2014 Gert Wollny
  *
  * MIA is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -58,24 +58,15 @@ struct __adjust<T3DVector<int> > {
 	}
 };
 
-using boost::filesystem::path; 
-C3DShapePluginHandlerTestPath::C3DShapePluginHandlerTestPath()
-{
-	CPathNameArray sksearchpath; 
-	sksearchpath.push_back( path(MIA_BUILD_ROOT"/mia/3d/shapes"));
-	C3DShapePluginHandler::set_search_path(sksearchpath); 
-}
-
 template <> const char *  const 
 TPluginHandler<TFactory<C3DShape>>::m_help =  "These plug-ins define 3D structuring elements "
 				"to describe neighborhoods for morphological and other filters."; 
 
-
+template class TShape<T3DVector, C3DBitImage>;
 template class TPlugin<C3DImage, shape_type>;
 template class TFactory<C3DShape>;
 template class THandlerSingleton<TFactoryPluginHandler<C3DShapePlugin> >;
 template class TFactoryPluginHandler<C3DShapePlugin>;
-template class TPluginHandler<C3DShapePlugin>;
-template class TShape<T3DVector, C3DBitImage>;
+template class EXPORT_3D TPluginHandler<C3DShapePlugin>;
 
 NS_MIA_END
