@@ -1,7 +1,7 @@
 /* -*- mia-c++  -*-
  *
  * This file is part of MIA - a toolbox for medical image analysis 
- * Copyright (c) Leipzig, Madrid 1999-2013 Gert Wollny
+ * Copyright (c) Leipzig, Madrid 1999-2014 Gert Wollny
  *
  * MIA is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -174,40 +174,6 @@ void C3DRigidTransformation::set_parameters(const CDoubleVector& params)
 	m_matrix_valid = false;
 }
 
-float C3DRigidTransformation::divergence() const
-{
-	return 0.0;
-}
-
-float C3DRigidTransformation::grad_divergence() const
-{
-	return 0.0;
-}
-
-
-float C3DRigidTransformation::grad_curl() const
-{
-	return 0.0;
-}
-
-
-float C3DRigidTransformation::curl() const
-{
-	// this is not right
-	return 0.0;
-}
-
-double C3DRigidTransformation::get_divcurl_cost(double /*wd*/, double /*wr*/, CDoubleVector& /*gradient*/) const
-{
-	return 0.0; 
-}
-
-double C3DRigidTransformation::get_divcurl_cost(double /*wd*/, double /*wr*/) const
-{
-	return 0.0; 
-}
-
-
 const C3DBounds& C3DRigidTransformation::get_size() const
 {
 	return m_size;
@@ -482,8 +448,9 @@ C3DRigidTransformCreatorPlugin::C3DRigidTransformCreatorPlugin():
 	C3DTransformCreatorPlugin("rigid"), 
 	m_relative_rot_center(0,0,0)
 {
-	add_parameter("rot-center", make_param(m_relative_rot_center, false, "Relative rotation center, i.e.  <0.5,0.5,0.5> corresponds "
-					       "to the center of the volume"));
+	add_parameter("origin", make_param(m_relative_rot_center, false, 
+					   "Relative rotation center, i.e.  <0.5,0.5,0.5> corresponds "
+					   "to the center of the volume"));
 }
 
 C3DTransformCreator *C3DRigidTransformCreatorPlugin::do_create(const C3DInterpolatorFactory& ipf) const
