@@ -1,7 +1,7 @@
 /* -*- mia-c++  -*-
  *
  * This file is part of MIA - a toolbox for medical image analysis 
- * Copyright (c) Leipzig, Madrid 1999-2013 Gert Wollny
+ * Copyright (c) Leipzig, Madrid 1999-2014 Gert Wollny
  *
  * MIA is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -26,6 +26,7 @@
 #include <cmath>
 #include <sstream>
 #include <mia/3d/transform/spline.hh>
+#include <mia/3d/transform/vectorfield.hh>
 #include <mia/3d/transformfactory.hh>
 #include <mia/3d/imageio.hh>
 #include <mia/core/index.hh>
@@ -158,6 +159,11 @@ C3DSplineTransformation::~C3DSplineTransformation()
 {
 }
 
+C3DBounds C3DSplineTransformation::get_minimal_supported_image_size() const
+{
+	return C3DBounds(ceil(m_target_c_rate.x), ceil(m_target_c_rate.y), ceil(m_target_c_rate.z))  + C3DBounds::_1; 
+}
+
 void C3DSplineTransformation::set_coefficients(const C3DFVectorfield& field)
 {
 	TRACE_FUNCTION;
@@ -1020,42 +1026,6 @@ bool C3DSplineTransformation::do_has_energy_penalty() const
 	return m_penalty.operator bool(); 
 }
 
-double C3DSplineTransformation::get_divcurl_cost(double wd, double wr, CDoubleVector& gradient) const
-{
-	TRACE_FUNCTION;
-//	FUNCTION_NOT_TESTED;
-	reinit(); 
-
-	// create PP matrices or adapt size 
-	if (!m_divcurl_matrix) 
-		m_divcurl_matrix.reset(new C3DPPDivcurlMatrix(m_coefficients.get_size(), 
-							       C3DFVector(m_range), 
-							       *m_kernel, wd, wr)); 
-	else 
-		m_divcurl_matrix->reset(m_coefficients.get_size(), C3DFVector(m_range), 
-					 *m_kernel, wd, wr); 
-	
-	
-	return m_divcurl_matrix->evaluate(m_coefficients, gradient); 
-}
-
-double C3DSplineTransformation::get_divcurl_cost(double wd, double wr) const
-{
-	TRACE_FUNCTION;
-
-	reinit(); 
-	// create PP matrices or adapt size 
-	if (!m_divcurl_matrix) 
-		m_divcurl_matrix.reset(new C3DPPDivcurlMatrix(m_coefficients.get_size(), C3DFVector(m_range), 
-							       *m_kernel, wd, wr)); 
-	else 
-		m_divcurl_matrix->reset(m_coefficients.get_size(), C3DFVector(m_range), 
-					 *m_kernel, wd, wr); 
-	
-
-	return *m_divcurl_matrix * m_coefficients; 
-}
-
 
 class C3DSplinebigTransformCreator: public C3DTransformCreator {
 public:
@@ -1153,7 +1123,9 @@ const std::string C3DSplineTransformCreatorPlugin::do_get_descr() const
 
 extern "C" EXPORT CPluginBase *get_plugin_interface()
 {
-	return new C3DSplineTransformCreatorPlugin();
+	auto p = new C3DGridTransformCreatorPlugin();
+	p->append_interface(new C3DSplineTransformCreatorPlugin()); 
+	return p; 
 }
 
 NS_MIA_END
