@@ -1,7 +1,7 @@
 /* -*- mia-c++  -*-
  *
  * This file is part of MIA - a toolbox for medical image analysis 
- * Copyright (c) Leipzig, Madrid 1999-2013 Gert Wollny
+ * Copyright (c) Leipzig, Madrid 1999-2014 Gert Wollny
  *
  * MIA is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -363,16 +363,6 @@ float C3DGridTransformation::pertuberate(C3DFVectorfield& v) const
 }
 
 
-double C3DGridTransformation::get_divcurl_cost(double wd, double wr, CDoubleVector& gradient) const
-{
-	DEBUG_ASSERT_RELEASE_THROW(false, "C3DGridTransformation::get_divcurl_cost not implemented."); 
-}
-
-double C3DGridTransformation::get_divcurl_cost(double wd, double wr) const
-{
-	DEBUG_ASSERT_RELEASE_THROW(false, "C3DGridTransformation::get_divcurl_cost not implemented."); 
-}
-
 
 float C3DGridTransformation::get_jacobian(const C3DFVectorfield& v, float delta) const
 {
@@ -453,11 +443,5 @@ const std::string C3DGridTransformCreatorPlugin::do_get_descr() const
 		"each point of the grid defining the domain of the transformation.";
 }
 
-extern "C" EXPORT CPluginBase *get_plugin_interface()
-{
-	return new C3DGridTransformCreatorPlugin();
-}
-
-
 
 NS_MIA_END
