@@ -1,7 +1,7 @@
 /* -*- mia-c++  -*-
  *
  * This file is part of MIA - a toolbox for medical image analysis 
- * Copyright (c) Leipzig, Madrid 1999-2013 Gert Wollny
+ * Copyright (c) Leipzig, Madrid 1999-2014 Gert Wollny
  *
  * MIA is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -26,14 +26,6 @@
 
 NS_MIA_BEGIN
 
-C3DTransformCreatorHandlerTestPath::C3DTransformCreatorHandlerTestPath()
-{
-	CPathNameArray kernelsearchpath;
-	kernelsearchpath.push_back(bfs::path(MIA_BUILD_ROOT"/mia/3d/transform"));
-	C3DTransformCreatorHandler::set_search_path(kernelsearchpath);
-}
-
-
 
 template <> const char *  const 
 TPluginHandler<C3DTransformCreatorPlugin>::m_help =  
