@@ -1,7 +1,7 @@
 /* -*- mia-c++  -*-
  *
  * This file is part of MIA - a toolbox for medical image analysis 
- * Copyright (c) Leipzig, Madrid 1999-2013 Gert Wollny
+ * Copyright (c) Leipzig, Madrid 1999-2014 Gert Wollny
  *
  * MIA is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -24,6 +24,7 @@
 #include <cstring>
 #include <iostream>
 #include <iomanip>
+#include <fstream>
 #include <map>
 #include <ctype.h>
 #include <stdexcept>
@@ -52,6 +53,7 @@ NS_MIA_BEGIN
 extern char const *get_revision(); 
 
 using std::ostream;
+using std::ofstream;
 using std::ostringstream;
 using std::string;
 using std::invalid_argument; 
@@ -81,7 +83,7 @@ struct CCmdOptionListData {
 	vector<string> remaining;
 
 	bool help;
-	bool help_xml; 
+	string help_xml; 
 	bool usage;
 	bool version; 
 	bool copyright;
@@ -151,14 +153,13 @@ string CCmdOptionListData::set_description_value(EProgramDescriptionEntry entry,
 const char *g_help_optiongroup="Help & Info"; 
 const char *g_default_author = "Gert Wollny"; 
 const char *g_basic_copyright1 = "This software is Copyright (c) "; 
-const char *g_basic_copyright2 = " 1999-2013 Leipzig, Germany and Madrid, Spain. "
+const char *g_basic_copyright2 = " 1999-2014 Leipzig, Germany and Madrid, Spain. "
 	      "It comes with ABSOLUTELY NO WARRANTY and you may redistribute it "
 	      "under the terms of the GNU GENERAL PUBLIC LICENSE Version 3 (or later). "
 	      "For more information run the program with the option '--copyright'.\n"; 
 
 CCmdOptionListData::CCmdOptionListData(const SProgramDescription& description):
 	help(false),
-	help_xml(false), 
 	usage(false),
 	version(false), 
 	copyright(false),
@@ -301,12 +302,7 @@ void CCmdOptionListData::print_help_xml(const char *name_help, const CPluginHand
 			if (opt.get_long_option() == string("help-xml")) 
 				continue; 
 			
-			Element* option = group->add_child("option"); 
-			option->set_attribute("short", to_string<char>(opt.get_short_option()));
-			option->set_attribute("long", opt.get_long_option());
-			option->set_attribute("required", to_string<bool>(opt.is_required())); 
-			option->set_attribute("default", opt.get_value_as_string()); 
-			option->set_child_text(opt.get_long_help_xml(*option, handler_help_map));
+			opt.add_option_xml(*group, handler_help_map); 
 			
 			if (opt.is_required()) {
 				if (opt.get_short_option())
@@ -340,8 +336,10 @@ void CCmdOptionListData::print_help_xml(const char *name_help, const CPluginHand
 	Element* cr = nodeRoot->add_child("Author");
 	cr->set_child_text(m_author); 
 
-	*m_log << doc->write_to_string_formatted();
-	*m_log << "\n"; 
+	ofstream xmlfile(help_xml.c_str());  
+	
+	xmlfile << doc->write_to_string_formatted();
+	xmlfile << "\n"; 
 }
 
 /**
@@ -710,7 +708,7 @@ CCmdOptionList::do_parse(size_t argc, const char *args[], bool has_additional,
 	if (m_impl->help) {
 		m_impl->print_help(name_help, has_additional);
 		return hr_help;
-	}else if (m_impl->help_xml) {
+	}else if (!m_impl->help_xml.empty()) {
 		m_impl->print_help_xml(name_help, additional_help);
 		return hr_help_xml;
 	} else if (m_impl->usage) {
@@ -779,7 +777,7 @@ CHistoryRecord CCmdOptionList::get_values() const
 }
 
 CHelpOption::CHelpOption(Callback *cb, char short_opt, const char *long_opt, const char *long_help):
-	CCmdOption(short_opt, long_opt, long_help, NULL, false), 
+	CCmdOption(short_opt, long_opt, long_help, NULL, CCmdOptionFlags::none), 
 	m_callback(cb)
 {
 }
@@ -817,7 +815,7 @@ void CHelpOption::do_write_value(std::ostream& /*os*/) const
 CCmdFlagOption::CCmdFlagOption(int& val, const CFlagString& map, char short_opt, 
 			       const char *long_opt, const char *long_help, 
 			       const char *short_help, 
-			       bool flags):
+			       CCmdOptionFlags flags):
 	CCmdOption(short_opt, long_opt, long_help,short_help, flags),
 	m_value(val),
 	m_map(map)
@@ -853,7 +851,7 @@ size_t CCmdFlagOption::do_get_needed_args() const
 
 PCmdOption EXPORT_CORE make_opt(int& value, const CFlagString& map, const char *long_opt, 
 				char short_opt,const char *long_help, 
-				const char *short_help, bool flags)
+				const char *short_help, CCmdOptionFlags flags)
 {
 	return PCmdOption(new CCmdFlagOption(value, map, short_opt, long_opt,
                           long_help, short_help, flags ));
@@ -867,10 +865,10 @@ PCmdOption EXPORT_CORE make_help_opt(const char *long_opt, char short_opt,
 }
 
 PCmdOption EXPORT_CORE make_opt(std::string& value, const char *long_opt, char short_opt, const char *long_help, 
-				bool required, const CPluginHandlerBase *plugin_hint)
+				CCmdOptionFlags flags, const CPluginHandlerBase *plugin_hint)
 {
 	return PCmdOption(new CCmdStringOption(value, short_opt, long_opt, long_help, 
-					       required, plugin_hint)); 
+					       flags, plugin_hint)); 
 }
 
 PCmdOption EXPORT_CORE make_opt(bool& value, const char *long_opt, char short_opt, const char *help)
