@@ -1,7 +1,7 @@
 /* -*- mia-c++  -*-
  *
  * This file is part of MIA - a toolbox for medical image analysis 
- * Copyright (c) Leipzig, Madrid 1999-2013 Gert Wollny
+ * Copyright (c) Leipzig, Madrid 1999-2014 Gert Wollny
  *
  * MIA is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -90,4 +90,15 @@ std::string CPluginHandlerBase::do_get_handler_type_string() const
 }
 
 
+bool CPluginHandlerBase::validate_parameter_string(const std::string& s) const
+{
+	return do_validate_parameter_string(s);
+}
+
+bool CPluginHandlerBase::do_validate_parameter_string(const std::string& MIA_PARAM_UNUSED(s)) const
+{
+	return true; 
+}
+
+
 NS_MIA_END
