@@ -1,7 +1,7 @@
 /* -*- mia-c++  -*-
  *
  * This file is part of MIA - a toolbox for medical image analysis 
- * Copyright (c) Leipzig, Madrid 1999-2013 Gert Wollny
+ * Copyright (c) Leipzig, Madrid 1999-2014 Gert Wollny
  *
  * MIA is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -54,9 +54,6 @@ const char *minimizer_property = "CMinimizerMock";
 
 BOOST_AUTO_TEST_CASE( test_load_minimizer_plugins )	
 {
-	CPathNameArray  searchpath({bfs::path("minimizer")}); 
-	CMinimizerPluginHandler::set_search_path(searchpath); 
-
 	const CMinimizerPluginHandler::Instance& handler = CMinimizerPluginHandler::instance();
 
 	BOOST_CHECK_EQUAL(handler.size(), 3u); 
