@@ -1,7 +1,7 @@
 /* -*- mia-c++  -*-
  *
  * This file is part of MIA - a toolbox for medical image analysis 
- * Copyright (c) Leipzig, Madrid 1999-2013 Gert Wollny
+ * Copyright (c) Leipzig, Madrid 1999-2014 Gert Wollny
  *
  * MIA is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -34,9 +34,6 @@ NS_MIA_USE
 using namespace std;
 using namespace boost;
 
-CSplineKernelTestPath init_path; 
-CSplineBoundaryConditionTestPath bc_path; 
-
 BOOST_AUTO_TEST_CASE( test_plugin_availability ) 
 {
 	const auto& handler = CSplineKernelPluginHandler::instance();
