@@ -1,7 +1,7 @@
 /* -*- mia-c++  -*-
  *
  * This file is part of MIA - a toolbox for medical image analysis 
- * Copyright (c) Leipzig, Madrid 1999-2013 Gert Wollny
+ * Copyright (c) Leipzig, Madrid 1999-2014 Gert Wollny
  *
  * MIA is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -61,7 +61,7 @@ void SlopeClassifierFixture::run(size_t length, size_t components, const float *
 		for (size_t c = 0; c < components; ++c, ++i)
 			columns[c][r]  = *i;
 
-	CWaveletSlopeClassifier c(columns, mean_stripped);
+	CWaveletSlopeClassifier c(columns, mean_stripped, -1);
 	check_equal(c.get_movement_idx(), result.periodic_idx, "periodic index"); 
 	check_equal(c.get_RV_idx(), result.RV_idx, "RV index");
 	
@@ -427,7 +427,7 @@ BOOST_FIXTURE_TEST_CASE( test_classifier_5_O1a , SlopeClassifierFixture )
 		2.08701,   4.45134,  -1.44584,  -4.01091,  -4.37968,
 		4.04924,   3.69677,-0.0889484,  -9.95966, -0.413756,
 		0.585227,   2.99372, -0.863572,  -4.15864,   8.00943,
-		-1.20131,   3.27061,-0.0777571,  -2.53295,   8.29044,
+		-1.20141,   3.27061,-0.0777571,  -2.53295,   8.29044,
 		-0.711145,   4.17774,   1.73297,  -1.58116,  -4.50367,
 		2.30682,   3.01388,   2.83435,  -5.12192,  -5.33368,
 		0.669934,   2.71462,   3.84647,  -8.90214,   1.42903,
@@ -529,7 +529,7 @@ BOOST_FIXTURE_TEST_CASE( test_classifier_5_O1b , SlopeClassifierFixture )
 		-0.847239,   11.0478,   2.29227,  0.515116,  -0.50884,
 		0.904234,    5.8041,    1.0846,  -10.7599,  0.766765,
 		0.602109,  -1.42075,   1.70485,  -7.12815, -0.957428,
-		0.20139,  -2.01366,   1.93427,  0.956927,  -1.35333,
+		0.20149,  -2.01366,   1.93427,  0.956927,  -1.35333,
 		-0.358474,   4.57577,   1.49353,    5.6365,  -2.09492,
 		0.70094,   7.10685,   1.04098,  -8.12112,  -1.63661,
 		1.09538,   2.19787,  0.563649,  -11.1879,  0.513716,
