@@ -1,7 +1,7 @@
 /* -*- mia-c++  -*-
  *
  * This file is part of MIA - a toolbox for medical image analysis 
- * Copyright (c) Leipzig, Madrid 1999-2013 Gert Wollny
+ * Copyright (c) Leipzig, Madrid 1999-2014 Gert Wollny
  *
  * MIA is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -55,16 +55,16 @@ struct CWaveletSlopeClassifierImpl {
 	typedef vector<float>::const_iterator position;
 	typedef pair<position, position> extrems;
 	typedef pair<size_t, size_t> extrems_pos;
-	CWaveletSlopeClassifierImpl(const CWaveletSlopeClassifier::Columns& series, bool mean_stripped);
+	CWaveletSlopeClassifierImpl(const CWaveletSlopeClassifier::Columns& series, bool mean_stripped, float min_freq);
 	CWaveletSlopeClassifierImpl(); 
 };
 
 
-CWaveletSlopeClassifier::CWaveletSlopeClassifier(const CWaveletSlopeClassifier::Columns& m, bool mean_stripped)
+CWaveletSlopeClassifier::CWaveletSlopeClassifier(const CWaveletSlopeClassifier::Columns& m, bool mean_stripped, float min_freq)
 {
 	if (m.size() < 3)
 		throw invalid_argument("CWaveletSlopeClassifier: require at least 3 curves");
-	impl = new CWaveletSlopeClassifierImpl(m, mean_stripped);
+	impl = new CWaveletSlopeClassifierImpl(m, mean_stripped, min_freq);
 }
 
 CWaveletSlopeClassifier::CWaveletSlopeClassifier(const CWaveletSlopeClassifier& other):
@@ -75,7 +75,7 @@ CWaveletSlopeClassifier::CWaveletSlopeClassifier():
 	impl(new CWaveletSlopeClassifierImpl())
 {
 }
-		     
+	     
 CWaveletSlopeClassifier& CWaveletSlopeClassifier::operator =(const CWaveletSlopeClassifier& other)
 {
 	if (this != &other) {
@@ -160,7 +160,7 @@ CWaveletSlopeClassifierImpl::CWaveletSlopeClassifierImpl():
 {
 }
 
-CWaveletSlopeClassifierImpl::CWaveletSlopeClassifierImpl(const CWaveletSlopeClassifier::Columns& series, bool mean_stripped):
+CWaveletSlopeClassifierImpl::CWaveletSlopeClassifierImpl(const CWaveletSlopeClassifier::Columns& series, bool mean_stripped, float min_freq):
 	RV_peak(-1), 
 	LV_peak(-1), 
 	RV_idx(-1), 
@@ -172,6 +172,7 @@ CWaveletSlopeClassifierImpl::CWaveletSlopeClassifierImpl(const CWaveletSlopeClas
 	max_movment_energy(0.0), 
 	n_movement_components(0), 
 	result(CWaveletSlopeClassifier::wsc_fail)
+
 {
 	vector<PSlopeStatistics> vstats; 
 	for (unsigned int i = 0; i < series.size(); ++i)
@@ -194,17 +195,25 @@ CWaveletSlopeClassifierImpl::CWaveletSlopeClassifierImpl(const CWaveletSlopeClas
 
 
 	cvdebug() << "Movement coeff weights:" << movement_pos << "\n"; 
-	bool ifree_breathing = ((movement_pos[CSlopeStatistics::ecp_center] > movement_pos[CSlopeStatistics::ecp_begin]) &&
-				(movement_pos[CSlopeStatistics::ecp_center] > movement_pos[CSlopeStatistics::ecp_end]));
-
-	// handle free breathing and series that only end with breath holding in the same way 
-	if  ((!ifree_breathing) && (movement_pos[CSlopeStatistics::ecp_end] < movement_pos[CSlopeStatistics::ecp_begin]))
-		ifree_breathing = true; 
 	
-	if (ifree_breathing) 
+	int skip_idx = 0; 
+	bool ifree_breathing = false; 
+	if (min_freq != 0.0) {
+		((movement_pos[CSlopeStatistics::ecp_center] > movement_pos[CSlopeStatistics::ecp_begin]) &&
+		 (movement_pos[CSlopeStatistics::ecp_center] > movement_pos[CSlopeStatistics::ecp_end]));
+		
+		// handle free breathing and series that only end with breath holding in the same way 
+		if  ((!ifree_breathing) && (movement_pos[CSlopeStatistics::ecp_end] < movement_pos[CSlopeStatistics::ecp_begin]))
+			ifree_breathing = true; 
+	}else 
+		skip_idx = 1; 
+	
+
+	if (ifree_breathing) {
 		cvmsg() << "Detected data set with (initial) free breathing.\n"; 
-	else 
+	}else {
 		cvmsg() << "Detected data set with initial breath holding.\n"; 
+	}
 	
 	int low_energy_start_idx = 1; //ifree_breathing ? 0 : 1;
 	
@@ -217,6 +226,7 @@ CWaveletSlopeClassifierImpl::CWaveletSlopeClassifierImpl(const CWaveletSlopeClas
 	int min_range_idx = -1; 
 	float min_range  = numeric_limits<float>::max(); 
 
+	bool got_movement = false; 
 	vector<bool> is_high_freq(series.size()); 
 	for (size_t i = 0; i < series.size(); ++i) {
 		auto e = vstats[i]->get_level_coefficient_sums(); 
@@ -225,7 +235,7 @@ CWaveletSlopeClassifierImpl::CWaveletSlopeClassifierImpl(const CWaveletSlopeClas
 			  << " end= " << movement_idx - 1
 			  << "\n"; 
 
-		float low_freq = accumulate(e.begin() + low_energy_start_idx, e.begin() + movement_idx, 0.0); 
+		float low_freq = accumulate(e.begin() + low_energy_start_idx, e.begin() + movement_idx-skip_idx, 0.0); 
 		float high_freq = e[movement_idx] + e[movement_idx + 1];
 		
 		if (min_range > vstats[i]->get_range()) {
@@ -248,8 +258,25 @@ CWaveletSlopeClassifierImpl::CWaveletSlopeClassifierImpl(const CWaveletSlopeClas
 				is_high_freq[i] = false; 
 			}
 		}
+		got_movement |= is_high_freq[i]; 
 	}
-
+	
+	// got no movement, try with frequency analysis 
+	if (!got_movement && min_freq > 0.0f) {
+		for (size_t i = 0; i < series.size(); ++i) {
+			is_high_freq[i] = vstats[i]->get_mean_frequency() > min_freq; 
+			if (is_high_freq[i]) {
+				if (vstats[i]->get_mean_energy_position() == CSlopeStatistics::ecp_begin) {
+					cvinfo() << "c=" << i << ":override motion because we assume it's RV enhacement\n";
+					is_high_freq[i] = false; 
+				}
+				cvinfo() << "Slope " << i << " << detected as movement based on mean frequency slot " << vstats[i]->get_mean_frequency() << "\n"; 
+			}else 
+				cvinfo() << "Slope " << i << " << rejected as movement based on mean frequency slot " << vstats[i]->get_mean_frequency() << "\n"; 
+		}
+	}
+	
+	
 
 	// if the mean is stripped, the baseline vanishes 
 	if (mean_stripped) {
