@@ -1,7 +1,7 @@
 /* -*- mia-c++  -*-
  *
  * This file is part of MIA - a toolbox for medical image analysis 
- * Copyright (c) Leipzig, Madrid 1999-2013 Gert Wollny
+ * Copyright (c) Leipzig, Madrid 1999-2014 Gert Wollny
  *
  * MIA is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -100,8 +100,10 @@ int do_main( int argc, char *argv[] )
 	const auto& image2dio = C2DImageIOPluginHandler::instance();
 
 	CCmdOptionList options(g_description);
-	options.add(make_opt( in_filename, "in-files", 'i', "input image(s)", CCmdOption::required, &image2dio));
-	options.add(make_opt( mask_filename, "mask-file", 'm', "mask image, must be of type byte", CCmdOption::required, &image2dio));
+	options.add(make_opt( in_filename, "in-files", 'i', "input image(s)", 
+			      CCmdOptionFlags::required_input, &image2dio));
+	options.add(make_opt( mask_filename, "mask-file", 'm', "mask image, must be of type byte", 
+			      CCmdOptionFlags::required_input, &image2dio));
 
 	if (options.parse(argc, argv, "image") != CCmdOptionList::hr_no) 
 		return EXIT_SUCCESS; 
