@@ -1,7 +1,7 @@
 /* -*- mia-c++  -*-
  *
  * This file is part of MIA - a toolbox for medical image analysis 
- * Copyright (c) Leipzig, Madrid 1999-2013 Gert Wollny
+ * Copyright (c) Leipzig, Madrid 1999-2014 Gert Wollny
  *
  * MIA is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -38,7 +38,7 @@
 #include <mia/2d/imageio.hh>
 #include <mia/2d/filter.hh>
 #include <mia/2d/ica.hh>
-#include <mia/2d/SegSetWithImages.hh>
+#include <mia/2d/segsetwithimages.hh>
 #include <mia/2d/fuzzyseg.hh>
 #include <mia/2d/perfusion.hh>
 #include <mia/2d/transformfactory.hh>
@@ -426,10 +426,12 @@ int do_main( int argc, char *argv[] )
 
 	CCmdOptionList options(g_description);
 	options.set_group("File-IO"); 
-	options.add(make_opt( in_filename, "in-file", 'i', "input perfusion data set", CCmdOption::required));
+	options.add(make_opt( in_filename, "in-file", 'i', "input perfusion data set", 
+			      CCmdOptionFlags::required_input));
 	options.add(make_opt( out_filename, "out-file", 'o', "output myocardial mask", 
-			      CCmdOption::required, &imageio));
-	options.add(make_opt( save_feature, "save-features", 'f', "save ICA features to files with this name base")); 
+			      CCmdOptionFlags::required_output, &imageio));
+	options.add(make_opt( save_feature, "save-features", 'f', "save ICA features to files with this name base", 
+			      CCmdOptionFlags::output)); 
 
 	options.set_group("ICA");
 	options.add(make_opt( components, "components", 'C', "ICA components 0 = automatic estimation testing 4 and 5"));
