@@ -1,7 +1,7 @@
 /* -*- mia-c++  -*-
  *
  * This file is part of MIA - a toolbox for medical image analysis 
- * Copyright (c) Leipzig, Madrid 1999-2013 Gert Wollny
+ * Copyright (c) Leipzig, Madrid 1999-2014 Gert Wollny
  *
  * MIA is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -29,7 +29,7 @@
 #include <mia/internal/main.hh>
 #include <mia/2d/imageio.hh>
 #include <mia/2d/correlation_weight.hh>
-#include <mia/2d/SegSetWithImages.hh>
+#include <mia/2d/segsetwithimages.hh>
 
 NS_MIA_USE;
 using namespace std;
@@ -89,9 +89,9 @@ int do_main( int argc, char *argv[] )
 
 
 	CCmdOptionList options(g_description);
-	options.add(make_opt( src_name, "in", 'i', "input segmentation set", CCmdOption::required));
+	options.add(make_opt( src_name, "in", 'i', "input segmentation set", CCmdOptionFlags::required_input));
 	options.add(make_opt( out_name, "out", 'o', "output image of minimal correlation", 
-			      CCmdOption::required,  &C2DImageIOPluginHandler::instance()));
+			      CCmdOptionFlags::required_output,  &C2DImageIOPluginHandler::instance()));
 	options.add(make_opt( skip, "skip", 'k', "skip images at beginning of series"));
 
 	if (options.parse(argc, argv) != CCmdOptionList::hr_no)
