@@ -1,7 +1,7 @@
 /* -*- mia-c++  -*-
  *
  * This file is part of MIA - a toolbox for medical image analysis 
- * Copyright (c) Leipzig, Madrid 1999-2013 Gert Wollny
+ * Copyright (c) Leipzig, Madrid 1999-2014 Gert Wollny
  *
  * MIA is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -45,8 +45,8 @@ int do_main(int argc, char **argv)
 
 	const auto& vfio =C3DVFIOPluginHandler::instance(); 
 
-	options.add(make_opt( vf1_filename, "in-file-1", '1', "input vector field 1", CCmdOption::required, &vfio));
-	options.add(make_opt( vf2_filename, "in-file-2", '2', "input vector field 2", CCmdOption::required, &vfio));
+	options.add(make_opt( vf1_filename, "in-file-1", '1', "input vector field 1", CCmdOptionFlags::required_input, &vfio));
+	options.add(make_opt( vf2_filename, "in-file-2", '2', "input vector field 2", CCmdOptionFlags::required_input, &vfio));
 	options.add(make_opt( delta, "delta", 'd', "Maximum difference between vector to be ignored"));
 
 	if (options.parse(argc, argv) != CCmdOptionList::hr_no)
