@@ -1,7 +1,7 @@
 /* -*- mia-c++  -*-
  *
  * This file is part of MIA - a toolbox for medical image analysis 
- * Copyright (c) Leipzig, Madrid 1999-2013 Gert Wollny
+ * Copyright (c) Leipzig, Madrid 1999-2014 Gert Wollny
  *
  * MIA is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -56,6 +56,7 @@ map<string, const CPluginHandlerBase*> collect_handlers()
 	ADD(C2DImageCostPluginHandler::instance);
 	ADD(C2DImageCreatorPluginHandler::instance);
 	ADD(C2DImageIOPluginHandler::instance);
+	ADD(C2DMaskedImageCostPluginHandler::instance);
 	ADD(C2DRegModelPluginHandler::instance);
 	ADD(C2DShapePluginHandler::instance);
 	ADD(C2DStackDistanceTransformIOPluginHandler::instance);
@@ -69,12 +70,14 @@ map<string, const CPluginHandlerBase*> collect_handlers()
 	ADD(C3DImageCostPluginHandler::instance);
 	ADD(C3DImageCreatorPluginHandler::instance);
 	ADD(C3DImageIOPluginHandler::instance);
+	ADD(C3DMaskedImageCostPluginHandler::instance);
 	ADD(C3DRegModelPluginHandler::instance);
 	ADD(C2DRegTimeStepPluginHandler::instance);
 	ADD(C3DRegTimeStepPluginHandler::instance);
 	ADD(C3DShapePluginHandler::instance);
 	ADD(C3DTransformationIOPluginHandler::instance);
 	ADD(C3DTransformCreatorHandler::instance);
+	ADD(C3DSplineTransformPenaltyPluginHandler::instance);
 	ADD(C3DVFIOPluginHandler::instance);
 	ADD(CCST2DImgKernelPluginHandler::instance);
 	ADD(CCST2DVectorKernelPluginHandler::instance);
