@@ -1,7 +1,7 @@
 /* -*- mia-c++  -*-
  *
  * This file is part of MIA - a toolbox for medical image analysis 
- * Copyright (c) Leipzig, Madrid 1999-2013 Gert Wollny
+ * Copyright (c) Leipzig, Madrid 1999-2014 Gert Wollny
  *
  * MIA is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -180,12 +180,12 @@ int do_main(int argc, char *argv[])
 
 	CCmdOptionList options(g_description);
 
-	options.add(make_opt( in_filename, "in-file", 'i', "input file name", CCmdOption::required));
-	options.add(make_opt( out_filename, "out-file", 'o', "output file name", CCmdOption::required, &imageio));
+	options.add(make_opt( in_filename, "in-file", 'i', "input file name", CCmdOptionFlags::required_input));
+	options.add(make_opt( out_filename, "out-file", 'o', "output file name", CCmdOptionFlags::required_output, &imageio));
 	options.add(make_opt( pixel_type, CPixelTypeDict, "repn", 'r',"input pixel type "));
 	options.add(make_opt( high_endian, "big-endian", 'b', "input data is big endian"));
 	options.add(make_opt( scale, "scale", 'f', "scale of input pixels <FX,FY>"));
-	options.add(make_opt( size, "size", 's', "size of input <NX,NY>", CCmdOption::required));
+	options.add(make_opt( size, "size", 's', "size of input <NX,NY>", CCmdOptionFlags::required));
 	options.add(make_opt( skip, "skip", 'k', "skip number of bytes from beginning of file"));
 
 	if (options.parse(argc, argv) != CCmdOptionList::hr_no)
